# pyzjr

<h1 align="center">
<img src="https://github.com/Auorui/AI-Learning-Materials/blob/main/webbg/%E5%86%B0%E7%BA%A2%E8%8C%B6.png" width="300">
</h1><br>

![Static Badge](https://img.shields.io/badge/GitHub-Auorui-bgr?link=https%3A%2F%2Fgithub.com%2FAuorui)
![Static Badge](https://img.shields.io/badge/Download-pyzjr-rgb?color=%233ABBEB&link=https%3A%2F%2Fpypi.org%2Fproject%2Fpyzjr)

This is a package that has been patched for excellent third-party libraries such as opencv and pytorch.

All useful functional functions written by individuals

I will also integrate algorithms I have previously written

## Installation

https://pypi.org/project/pyzjr/

https://github.com/Auorui/pyzjr (I want stars ⭐ hhh)

## Update log
`0.0.17——0.0xx` Added Showimage module and added torch framework. It is recommended to install it in a virtual environment of deep learning framework.

`0.0.12——0.016` Modifying bugs and adding functions to the PIC.py file.

`0.0.11` Created a new FM.py file and moved some functions of PIC over.

`0.0.10` Modified the position of the repair_Img function to PIC, added interactive annotations, which can be used for perspective transformation.

`0.0.9` Added mini module, can perform bucket operations.

`0.0.8` Can be used normally, added zmath file.

`0.0.7` fix bug.

`0.0.1` first release.

## Upload of Library

* `python setup.py sdist`

* `twine upload dist/*`